==> ejc-procost-impl-3.0.0-20220519.112115-25-sources.jar: com/ejianc/business/procost/bean/CostDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 数据明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_detail")
public class CostDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="subject_id")
    private java.lang.Long subjectId; // 科目主键
    @TableField(value="subject_code")
    private java.lang.String subjectCode; // 科目编号
    @TableField(value="subject_name")
    private java.lang.String subjectName; // 科目名称
    @TableField(value="wbs_id")
    private java.lang.Long wbsId; // 核算对象主键
    @TableField(value="wbs_code")
    private java.lang.String wbsCode; // 核算对象编号
    @TableField(value="wbs_name")
    private java.lang.String wbsName; // 核算对象名称
    @TableField(value="source_id")
    private java.lang.Long sourceId; // 来源单据主键ID
    @TableField(value="source_detail_id")
    private java.lang.Long sourceDetailId; // 来源单据明细主键ID
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目主键ID
    @TableField(value="happen_tax_mny")
    private java.math.BigDecimal happenTaxMny; // 发生成本(含税)
    @TableField(value="happen_mny")
    private java.math.BigDecimal happenMny; // 发生成本(不含税)
    @TableField(value="happen_date")
    private java.util.Date happenDate; // 发生日期
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 创建人名称
    @TableField(value="source_type")
    private java.lang.String sourceType; // 来源类型
    @TableField(value="source_tab_type")
    private java.lang.String sourceTabType; // 来源子表类型
    @TableField(value="period")
    private java.lang.String period; // 期间
    @TableField(value="proportion_flag")
    private java.lang.String proportionFlag; // 分摊状态(1:是，0：否)

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public String getProportionFlag() {
        return proportionFlag;
    }

    public void setProportionFlag(String proportionFlag) {
        this.proportionFlag = proportionFlag;
    }

    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }

    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    /**
     * 科目主键
     */
    public java.lang.Long getSubjectId() {
        return subjectId;
    }

    /**
     * 科目主键
     */
    public void setSubjectId(java.lang.Long subjectId) {
        this.subjectId = subjectId;
    }
    /**
     * 科目编号
     */
    public java.lang.String getSubjectCode() {
        return subjectCode;
    }

    /**
     * 科目编号
     */
    public void setSubjectCode(java.lang.String subjectCode) {
        this.subjectCode = subjectCode;
    }
    /**
     * 科目名称
     */
    public java.lang.String getSubjectName() {
        return subjectName;
    }

    /**
     * 科目名称
     */
    public void setSubjectName(java.lang.String subjectName) {
        this.subjectName = subjectName;
    }
    /**
     * 来源单据主键ID
     */
    public java.lang.Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源单据主键ID
     */
    public void setSourceId(java.lang.Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 来源单据明细主键ID
     */
    public java.lang.Long getSourceDetailId() {
        return sourceDetailId;
    }

    /**
     * 来源单据明细主键ID
     */
    public void setSourceDetailId(java.lang.Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    /**
     * 发生成本(含税)
     */
    public java.math.BigDecimal getHappenTaxMny() {
        return happenTaxMny;
    }

    /**
     * 发生成本(含税)
     */
    public void setHappenTaxMny(java.math.BigDecimal happenTaxMny) {
        this.happenTaxMny = happenTaxMny;
    }
    /**
     * 发生成本(不含税)
     */
    public java.math.BigDecimal getHappenMny() {
        return happenMny;
    }

    /**
     * 发生成本(不含税)
     */
    public void setHappenMny(java.math.BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    /**
     * 发生日期
     */
    public java.util.Date getHappenDate() {
        return happenDate;
    }

    /**
     * 发生日期
     */
    public void setHappenDate(java.util.Date happenDate) {
        this.happenDate = happenDate;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 来源类型
     */
    public java.lang.String getSourceType() {
        return sourceType;
    }

    /**
     * 来源类型
     */
    public void setSourceType(java.lang.String sourceType) {
        this.sourceType = sourceType;
    }
    /**
     * 来源子表类型
     */
    public java.lang.String getSourceTabType() {
        return sourceTabType;
    }

    /**
     * 来源子表类型
     */
    public void setSourceTabType(java.lang.String sourceTabType) {
        this.sourceTabType = sourceTabType;
    }
    
}

==> ejc-procost-impl-3.0.0-20220523.084539-31-sources.jar: com/ejianc/business/procost/bean/CostDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 数据明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_detail")
public class CostDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="subject_id")
    private java.lang.Long subjectId; // 科目主键
    @TableField(value="subject_code")
    private java.lang.String subjectCode; // 科目编号
    @TableField(value="subject_name")
    private java.lang.String subjectName; // 科目名称
    @TableField(value="wbs_id")
    private java.lang.Long wbsId; // 核算对象主键
    @TableField(value="wbs_code")
    private java.lang.String wbsCode; // 核算对象编号
    @TableField(value="wbs_name")
    private java.lang.String wbsName; // 核算对象名称
    @TableField(value="source_id")
    private java.lang.Long sourceId; // 来源单据主键ID
    @TableField(value="source_detail_id")
    private java.lang.Long sourceDetailId; // 来源单据明细主键ID
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目主键ID
    @TableField(value="happen_tax_mny")
    private java.math.BigDecimal happenTaxMny; // 发生成本(含税)
    @TableField(value="happen_mny")
    private java.math.BigDecimal happenMny; // 发生成本(不含税)
    @TableField(value="num")
    private java.math.BigDecimal num; // 发生数量
    @TableField(value="happen_date")
    private java.util.Date happenDate; // 发生日期
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 创建人名称
    @TableField(value="source_type")
    private java.lang.String sourceType; // 来源类型
    @TableField(value="source_tab_type")
    private java.lang.String sourceTabType; // 来源子表类型
    @TableField(value="period")
    private java.lang.String period; // 期间
    @TableField(value="proportion_flag")
    private java.lang.String proportionFlag; // 分摊状态(1:是，0：否)

    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }

    public String getProportionFlag() {
        return proportionFlag;
    }

    public void setProportionFlag(String proportionFlag) {
        this.proportionFlag = proportionFlag;
    }

    public Long getWbsId() {
        return wbsId;
    }

    public void setWbsId(Long wbsId) {
        this.wbsId = wbsId;
    }

    public String getWbsCode() {
        return wbsCode;
    }

    public void setWbsCode(String wbsCode) {
        this.wbsCode = wbsCode;
    }

    public String getWbsName() {
        return wbsName;
    }

    public void setWbsName(String wbsName) {
        this.wbsName = wbsName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    /**
     * 科目主键
     */
    public java.lang.Long getSubjectId() {
        return subjectId;
    }

    /**
     * 科目主键
     */
    public void setSubjectId(java.lang.Long subjectId) {
        this.subjectId = subjectId;
    }
    /**
     * 科目编号
     */
    public java.lang.String getSubjectCode() {
        return subjectCode;
    }

    /**
     * 科目编号
     */
    public void setSubjectCode(java.lang.String subjectCode) {
        this.subjectCode = subjectCode;
    }
    /**
     * 科目名称
     */
    public java.lang.String getSubjectName() {
        return subjectName;
    }

    /**
     * 科目名称
     */
    public void setSubjectName(java.lang.String subjectName) {
        this.subjectName = subjectName;
    }
    /**
     * 来源单据主键ID
     */
    public java.lang.Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源单据主键ID
     */
    public void setSourceId(java.lang.Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 来源单据明细主键ID
     */
    public java.lang.Long getSourceDetailId() {
        return sourceDetailId;
    }

    /**
     * 来源单据明细主键ID
     */
    public void setSourceDetailId(java.lang.Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    /**
     * 发生成本(含税)
     */
    public java.math.BigDecimal getHappenTaxMny() {
        return happenTaxMny;
    }

    /**
     * 发生成本(含税)
     */
    public void setHappenTaxMny(java.math.BigDecimal happenTaxMny) {
        this.happenTaxMny = happenTaxMny;
    }
    /**
     * 发生成本(不含税)
     */
    public java.math.BigDecimal getHappenMny() {
        return happenMny;
    }

    /**
     * 发生成本(不含税)
     */
    public void setHappenMny(java.math.BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    /**
     * 发生日期
     */
    public java.util.Date getHappenDate() {
        return happenDate;
    }

    /**
     * 发生日期
     */
    public void setHappenDate(java.util.Date happenDate) {
        this.happenDate = happenDate;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 来源类型
     */
    public java.lang.String getSourceType() {
        return sourceType;
    }

    /**
     * 来源类型
     */
    public void setSourceType(java.lang.String sourceType) {
        this.sourceType = sourceType;
    }
    /**
     * 来源子表类型
     */
    public java.lang.String getSourceTabType() {
        return sourceTabType;
    }

    /**
     * 来源子表类型
     */
    public void setSourceTabType(java.lang.String sourceTabType) {
        this.sourceTabType = sourceTabType;
    }
    
}
